OC.L10N.register(
    "federation",
    {
    "Server added to the list of trusted ownClouds" : "ownCloud の信頼済サイト に追加されているサーバー",
    "Server is already in the list of trusted servers." : "信頼済サイトとして既に登録されています。",
    "No ownCloud server found" : "ownCloudサーバーが見つかりません",
    "Could not add server" : "サーバーを追加できませんでした",
    "Federation" : "連携",
    "ownCloud Federation allows you to connect with other trusted ownClouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "ownCloud 連携機能では信頼済のownCloudのユーザーディレクトリを相互に接続することができます。例えば、連携で共有したときには、連携先の外部ユーザー名の自動補完を使えるようになります。",
    "Add server automatically once a federated share was created successfully" : "ownCloudサーバー連携で一度でも共有が作成できた場合は、サーバーを自動的に追加します。",
    "Trusted ownCloud Servers" : "信頼済 ownCloudサーバ",
    "+ Add ownCloud server" : "＋ownCloudサーバを追加",
    "ownCloud Server" : "ownCloudサーバ"
},
"nplurals=1; plural=0;");
